@@ -10,7 +10,7 @@ import copy
 from collections import deque
 
 from ..aid.sixing import *
-from .globaling import *
+from .globaling import INDENT_ADD, REO_IdentPub
 from ..aid.odicting import odict
 
 from . import excepting
@@ -18,33 +18,31 @@ from . import registering
 
 from ..aid.aiding import nameToPath
 
-from .consoling import getConsole
+from ..aid.consoling import getConsole
 console = getConsole()
 
 
 class Node(odict):
-    """ Special odict with name property to hold the pathname to the node
+    """
+    Special odict with name property to hold the pathname to the node
     """
     __slots__ = ('_name', ) # attribute supporting name property
 
-
     def __init__(self, *pa, **kwa):
         """ Initialize instance. name is empty """
         super(Node,self).__init__(*pa, **kwa)
-
         self._name = ""
 
-    #property name
-    def getName(self):
-        """getter for name property """
+    @property
+    def name(self):  #property name
+        """Get name property. Pathname to node."""
         return self._name
 
-    def setName(self, name):
-        """setter for name property """
+    @name.setter
+    def name(self, name):
+        """Set name property """
         self._name = name
 
-    name = property(fget = getName, fset = setName, doc = "Pathname to node.")
-
     def byName(self, name):
         """ Sets name and returns self.
             Enables setting name as part of method chaining.
@@ -189,7 +187,8 @@ class Store(registering.Registrar):
     def add(self, share):
         """Add share to store and change shares .store to self
            Creates node hierarchy from name as needed
-           If share already exists with same name then raises exception. Should use .change instead
+           If share already exists with same name then raises exception.
+           Should use .change instead is want to change path of existing share
            This is to prevent inadvertant adding of shares that clobber node hierarchy
 
            for a single item list
@@ -304,34 +303,47 @@ class Store(registering.Registrar):
 
         return self.addNode(name=name)
 
-    def expose(self, values=False):
-        """   """
+    def expose(self, valued=False):
+        """
+        If valued then display values for leaf share items
+        """
         console.terse("Store name= {0}, stamp= {1}\n".format(self.name, self.stamp))
         console.terse("Nodes & Shares:\n")
-        Store.ShowNode(self.shares, indent = 0, values=values)
+        Store.ShowNode(self.shares, indent = 0, valued=valued)
 
 
     @staticmethod
-    def ShowNode(node, indent = 0, values=False):
-        if isinstance(node, dict):
+    def ShowNode(node, indent=0, valued=False):
+        """
+        node is node to display
+        indent is number of spaces to indent
+        If valued then display values for leaf share items
+        """
+        if isinstance(node, dict):  # plain node
             for key, value in node.items():
                 msg = ""
                 for i in range(indent):
                     msg += "  "
                 msg += ".{0} ".format(key)
                 console.terse("{0}\n".format(msg))
-                Store.ShowNode(value, indent = indent + 1, values=values)
-        else:
+                Store.ShowNode(value, indent = indent + 1, valued=valued)
+        else:  # share leaf
             msg = ""
+            offset = ""
             for i in range(indent):
-                msg += "  "
-            if values:
+                offset += "  "
+            msg += offset
+            if valued:
                 for key, val in node.items():
                     msg += "{0}={1} ".format(key, val)
+                if node.deck:
+                    msg +=  "\n{0}deck={1}".format(offset, list(node.deck))
                 console.terse("{0}\n".format(msg))
             else:
                 for key in node.keys():
                     msg += "{0} ".format(key)
+                if node.deck:
+                    msg += "\n{0}deck".format(offset)
                 console.terse("{0}\n".format(msg))
 
 
@@ -410,8 +422,7 @@ class Share(object):
                  stamp=None,
                  unit=None,
                  owner=None,
-                 deck=None,
-                 **kwa):
+                 deck=None):
         """
         Initialize instance
 
@@ -506,7 +517,8 @@ class Share(object):
     def __repr__(self):
         """    """
         itemreprs = repr(self._data.__dict__)
-        return 'Share '  + itemreprs
+        deckreprs = repr(self.deck)
+        return ("Share(name={0}, data=Data({1}), deck={2})".format(self.name, itemreprs, deckreprs))
 
     def clear(self):
         """   """
@@ -581,37 +593,41 @@ class Share(object):
         return self.deck.pull()
 
     # properties
-    def getOwner(self):  # owner property
-        """getter for  owner property """
+    @property
+    def owner(self):  # owner property
+        """Get owner property"""
         return self._owner
 
-    def setOwner(self, owner):  # owner property
-        """setter for owner property """
+    @owner.setter
+    def owner(self, owner):  # owner property
+        """Set owner property """
         self._owner = owner
-    owner = property(fget = getOwner, fset = setOwner, doc = "Owner of share")
 
-    def getTruth(self):  # truth property
-        """getter for truth property """
+    @property
+    def truth(self):  # truth property
+        """Get truth property """
         return self._truth
 
-    def setTruth(self, truth):  # truth property
-        """setter for value property """
+    @truth.setter
+    def truth(self, truth):  # truth property
+        """Set truth property """
         self._truth = truth
-    truth = property(fget = getTruth, fset = setTruth, doc = "Truth for this share")
 
-    def getUnit(self):   # unit property
-        """getter for unit property """
+    @property
+    def unit(self):   # unit property
+        """Get unit property """
         return self._unit
 
-    def setUnit(self, unit): # unit property
-        """setter for unit property """
+    @unit.setter
+    def unit(self, unit): # unit property
+        """Set unit property """
         if not isinstance(unit, Data):
             raise ValueError("Not Data object %s" % unit)
         self._unit = unit
-    unit = property(fget = getUnit, fset = setUnit, doc = "Unit(s) for this share")
 
-    def getValue(self):  # value property
-        """getter for value property
+    @property
+    def value(self):  # value property
+        """Get value property
            returns none if no field in data of name 'value'
         """
         try:
@@ -619,23 +635,24 @@ class Share(object):
         except AttributeError:
             return None
 
-    def setValue(self, value):  # value property
-        """setter for value property """
+    @value.setter
+    def value(self, value):  # value property
+        """Set value property """
         setattr(self._data, 'value', value)
         self.stamp = self.store.stamp
-    value = property(fget = getValue, fset = setValue, doc = "Value for this share")
 
-    def getData(self):  # data property
-        """getter for data property """
+    @property
+    def data(self):  # data property
+        """Get data property """
         return self._data
 
-    def setData(self, data):  # data property
-        """setter for data property """
+    @data.setter
+    def data(self, data):  # data property
+        """Set data property """
         if not isinstance(data, Data):
             raise ValueError("Not Data object %s" % data)
         self._data = data
         self.stamp = self.store.stamp
-    data = property(fget = getData, fset = setData, doc = "Data for this share")
 
     def change(self, *pa, **kwa):
         """Change data fields without affecting stamp.
@@ -873,6 +890,13 @@ class Deck(deque):
     push = deque.append  # alias
     pull = deque.popleft  # alias
 
+
+    def __repr__(self):
+        """    """
+        itemreprs = repr(list(self))
+
+        return ("Deck({0})".format(itemreprs))
+
     def gulp(self, elem):
         """
         If not None, add elem to right side of deque, Otherwise ignore
